# This file is part of node_annotator.
#
# node_annotator is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# node_annotator is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with node_annotator.  If not, see <http://www.gnu.org/licenses/>.

# <pep8 compliant>

from . import annotate_ops
from . import search_ops
from . import refactor_ops
from . import control_panel
from . import annotation_painter
from . import preferences

import bpy


bl_info = {
    "name": "node_annotator",
    "author": "Frank Firsching",
    "description": "Utility tools for managing node graph annotations",
    "blender": (4, 0, 0),
    "version": (0, 4, 1),
    "location": "",
    "doc_url": "",
    "warning": "",
    "category": "Node"
}

classes = (
    annotate_ops.CreateAnnotation,
    annotate_ops.EditAnnotation,
    search_ops.SearchResultsProperties,
    search_ops.SearchSubGroup,
    search_ops.JumpToNode,
    refactor_ops.ReplaceNode,
    refactor_ops.ReplaceCurrentNode,
    refactor_ops.ReplaceAllNodes,
    control_panel.SearchResultsUIList,
    control_panel.NodeAnnotatorMainPanel,
    preferences.PreferencesPanel
)

the_annotation_painter = None

def register():
    global the_annotation_painter
    for cls in classes:
        bpy.utils.register_class(cls)
    the_annotation_painter = annotation_painter.AnnotationPainter()

def unregister():
    global the_annotation_painter
    the_annotation_painter.shutdown()
    the_annotation_painter = None
    for cls in reversed(classes):
        bpy.utils.unregister_class(cls)
