# This file is part of node_annotator.
#
# node_annotator is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# node_annotator is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with node_annotator.  If not, see <http://www.gnu.org/licenses/>.

# <pep8 compliant>

import bpy

from . import annotate_utils
from . import utils

def openTextEditor(text):
    # HACK: Open a new window by showing the user prefs...
    bpy.ops.screen.userpref_show("INVOKE_DEFAULT")
    # ... and then change its area type
    window = bpy.context.window_manager.windows[-1]
    area = window.screen.areas[0]
    area.type = "TEXT_EDITOR"
    area.spaces[0].text = text



class CreateAnnotation(bpy.types.Operator):
    """Create a new annotation in the given node graph"""
    bl_idname = "node_annotator.create_annotation"
    bl_label = "Create annotation"
    bl_options = {'REGISTER', 'UNDO'}

    def __init__(self):
        pass

    @classmethod
    def poll(cls, context):
        tree = context.space_data.edit_tree
        return tree is not None

    def execute(self, context):
        tree = context.space_data.edit_tree
        preferences = utils.get_preferences(context)
        note = annotate_utils.setup_annotation(tree, preferences.default_note_title, preferences.default_note_color)
        openTextEditor(note.text)

        return {'FINISHED'}

class EditAnnotation(bpy.types.Operator):
    """Edit an existing annotation"""
    bl_idname = "node_annotator.edit_annotation"
    bl_label = "Edit annotation"
    bl_options = {'REGISTER', 'UNDO'}

    def __init__(self):
        pass

    @classmethod
    def poll(cls, context):
        node = context.active_node
        return node is not None and node.select and node.bl_idname=="NodeFrame"

    def execute(self, context):
        tree = context.space_data.edit_tree
        node = context.active_node
        if node is not None and node.select and node.bl_idname=="NodeFrame":
            # In here the node is a note, so let's update its name (group might have had a name change)
            node.text.name = annotate_utils.textBlockName(tree, node)
            openTextEditor(node.text)

        return {'FINISHED'}
