# This file is part of node_annotator.
#
# node_annotator is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# node_annotator is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with node_annotator.  If not, see <http://www.gnu.org/licenses/>.

# <pep8 compliant>

import bpy

INFO_NODE_NAME = "Info"

def textBlockName(tree, node):
    """ Returns a common text block name throughout the add-on. """
    return 'Note - '+tree.name+"::"+node.label

def setup_annotation(tree, name:str="Note", color=(1,1,0)):
    active_node = tree.nodes.active
    note = tree.nodes.new('NodeFrame')
    note.name = name
    note.label = name
    note.label_size = 12
    note.shrink = False
    if active_node is not None and active_node.select:
        # Only if we have an active node and if it wasn't deselected again
        note.location = active_node.location
        note.location.y += active_node.height+10
    else:
        note.location = tree.view_center
    note.use_custom_color = True
    note.color = color
    text = bpy.data.texts.new(textBlockName(tree, note))
    text.use_fake_user = False # We attach the text directly to the note, let's delete it with the note
    note.text = text

    # Select the newly created node
    for n in tree.nodes:
        n.select = False
    note.select = True
    return note
