# This file is part of node_annotator.
#
# node_annotator is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# node_annotator is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with node_annotator.  If not, see <http://www.gnu.org/licenses/>.

# <pep8 compliant>

import blf
import gpu
import gpu_extras

def draw_text(pos_x, pos_y, size, text, color):
    """ Draw some text at given position """
    font_id = 0
    blf.position(font_id, pos_x, pos_y, 0)
    blf.size(font_id, size)
    blf.color(font_id, color[0], color[1], color[2], color[3])
    blf.draw(font_id, text)

def draw_text_lines(pos_x, pos_y, size, text, color):
    """ Draw some multiline text at given position """
    current_pos_y = pos_y
    for line in reversed(text):
        draw_text(pos_x, current_pos_y, size, line, color)
        current_pos_y += size


def draw_tinted_texture_2d(texture, color, position, width, height):
    """ Version of blender's draw_texture_2d, but with the ability to tint the image. """
    
    coords = ((0, 0), (1, 0), (1, 1), (0, 1))

    shader = gpu.shader.from_builtin('IMAGE_COLOR')
    batch = gpu_extras.batch.batch_for_shader(
        shader, 'TRI_FAN',
        {"pos": coords, "texCoord": coords},
    )

    with gpu.matrix.push_pop():
        gpu.matrix.translate(position)
        gpu.matrix.scale((width, height))
        shader.uniform_float("color", color)
        shader.uniform_sampler("image", texture)
        batch.draw(shader)
