# This file is part of node_annotator.
#
# node_annotator is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# node_annotator is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with node_annotator.  If not, see <http://www.gnu.org/licenses/>.

# <pep8 compliant>

import bpy
from bpy.props import BoolProperty, FloatVectorProperty, StringProperty

from . import utils

class PreferencesPanel(bpy.types.AddonPreferences):
    bl_idname = __package__

    show_description_icon: BoolProperty(name="Show description icon (Blender 4.2 feature)", default=True)
    default_note_title: StringProperty(name="Default Note Title", default="Note")
    default_note_color: FloatVectorProperty(name="Default Note Color", default=(0.6, 0.6, 0.2), subtype='COLOR_GAMMA')

    def draw(self, context):
        layout = self.layout.column()
        layout.prop(self, "show_description_icon")
        layout.prop(self, "default_note_title")
        layout.prop(self, "default_note_color")
        deployment_version = utils.get_deployment_version()
        if not "-0-" in deployment_version:
            # if the version is not directly on a version tag, let's add more detailed version info
            layout.label(text="Development version: "+deployment_version)
